@@ -186,6 +186,11 @@ class Generator:
         columns = ', '.join(self.sql(e) for e in expression.args.get('columns', []))
         return f"{this_sql}{op_sql}{self.sep()}{expression_sql} {alias} AS {columns}"
 
+    def limit_sql(self, expression):
+        this_sql = self.sql(expression, 'this')
+        limit = self.sql(expression, 'limit')
+        return f"{this_sql}{self.seg('LIMIT')} {limit}"
+
     def order_sql(self, expression, flat=False):
         sql = self.op_expressions('ORDER BY', expression, flat=flat)
         if expression.args['desc']:
@@ -193,7 +198,9 @@ class Generator:
         return sql
 
     def select_sql(self, expression):
-        return f"SELECT{self.sql(expression, 'hint')}{self.sep()}{self.expressions(expression)}"
+        hint_sql = self.sql(expression, 'hint')
+        distinct_sql = ' DISTINCT' if expression.args.get('distinct') else ''
+        return f"SELECT{hint_sql}{distinct_sql}{self.sep()}{self.expressions(expression)}"
 
     def union_sql(self, expression):
         distinct = '' if expression.args['distinct'] else ' ALL'
@@ -314,6 +321,9 @@ class Generator:
     def minus_sql(self, expression):
         return self.binary(expression, '-')
 
+    def mod_sql(self, expression):
+        return self.binary(expression, '%')
+
     def neq_sql(self, expression):
         return self.binary(expression, '<>')
 
